@@ -9,4 +9,4 @@ __author__ = 'Hyokeun Jeon'
 __author_email__ = 'hyokeun.jeon@samsung.com'
 __license__ = 'Apache 2.0'
 __copyright__ = 'Copyright 2020 Samsung Research'
-__cake__ = u'\u2728 \U0001f370 \u2728'
+__cake__ = '\\u2728 \\U0001f370 \\u2728'
