@@ -67,6 +67,8 @@ SUPPORTEDARCHS = [
     'armv7hl',
     'armv7l',
     'aarch64',
+    'aarch64ilp32',
+    'aarch64_ilp32',
     'mips',
     'mipsel',
     'riscv32',
