@@ -78,7 +78,7 @@ def guess_spec(git_path, packaging_dir, given_spec, commit_id='WC.UNTRACKED'):
                 outp = subprocess.Popen(cmd, stdout=subprocess.PIPE)
         except (subprocess.CalledProcessError, OSError):
             raise GbsError("failed to run %s in %s" % (' '.join(cmd), git_path))
-        output = outp.communicate()[0]
+        output = outp.communicate()[0].decode()
         if not output.startswith('tree %s' % git_object):
             # packaging_dir is a symlink
             packaging_dir = output
@@ -245,7 +245,7 @@ class URLGrabber(object):
         except pycurl.error as err:
             log.debug('fetching error:%s' % str(err))
 
-            errcode, errmsg = err.args
+            errcode, errmsg = err.args # pylint: disable=unbalanced-tuple-unpacking
             http_code = curl.getinfo(pycurl.HTTP_CODE)
 
             if errcode == pycurl.E_OPERATION_TIMEOUTED or http_code == 503:
@@ -280,7 +280,7 @@ class URLGrabber(object):
 
         log.debug("fetching %s => %s" % (url, filename))
 
-        with open(filename, 'w') as outfile:
+        with open(filename, 'wb') as outfile:
             self.change_url(url, outfile, user, passwd, no_cache)
             self.perform()
 
@@ -440,7 +440,7 @@ class RepoParser(object):
                     fh_gz = open(fname, 'r')
                 buildconf_file = os.path.join(os.path.dirname(fname),
                                               'build.conf')
-                buildconf_fh = open(buildconf_file, 'w')
+                buildconf_fh = open(buildconf_file, 'wb')
                 buildconf_fh.write(fh_gz.read())
                 fh_gz.close()
                 buildconf_fh.close()
@@ -621,10 +621,10 @@ class GerritNameMapper(object):
             log.warning('Not well formed xml pkgxml')
             return
 
-        lst_node = root.getiterator("package")
+        lst_node = root.iter("package")
         for node in lst_node:
-            if node.attrib.has_key("name"):
-                for child in node.getchildren():
+            if "name" in node.attrib:
+                for child in list(node):
                     if child.tag == 'source':
                         self._pkg2src[node.attrib['name']] = child.text
                         self._src2pkg[child.text] = node.attrib['name']
@@ -754,7 +754,7 @@ def show_file_from_rev(git_path, relative_path, commit_id):
     try:
         with Workdir(git_path):
             return  subprocess.Popen(args,
-                                     stdout=subprocess.PIPE).communicate()[0]
+                                     stdout=subprocess.PIPE).communicate()[0].decode()
     except (subprocess.CalledProcessError, OSError) as err:
         log.debug('failed to checkout %s from %s:%s' % (relative_path,
                                                         commit_id, str(err)))
@@ -777,7 +777,7 @@ def file_exists_in_rev(git_path, relative_path, commit_id, dir_only=False):
         raise GbsError('failed to check existence of %s in %s:%s' % (
             relative_path, commit_id, str(err)))
 
-    return output != ''
+    return output.decode() != ''
 
 
 def glob_in_inc(git_path, packaging_dir, pattern):
@@ -804,7 +804,7 @@ def glob_in_rev(git_path, pattern, commit_id):
         raise GbsError('failed to glob %s in %s:%s' % (
             pattern, commit_id, str(err)))
 
-    return fnmatch.filter(output.splitlines(), pattern)
+    return fnmatch.filter(output.decode().splitlines(), pattern)
 
 
 def get_editor_cmd():
